@@ -1,15 +1,18 @@
 from __future__ import unicode_literals
 
-from collections import OrderedDict
+import typing as T
 
 from conllu.exceptions import ParseException
 
+if T.TYPE_CHECKING:
+    from conllu.models import TokenList
 
-def serialize_field(field):
+
+def serialize_field(field: T.Any) -> str:
     if field is None:
         return '_'
 
-    if isinstance(field, OrderedDict):
+    if isinstance(field, dict):
         fields = []
         for key, value in field.items():
             if value is None:
@@ -29,7 +32,7 @@ def serialize_field(field):
 
     return "{}".format(field)
 
-def serialize(tokenlist):
+def serialize(tokenlist: 'TokenList') -> str:
     lines = []
 
     if tokenlist.metadata:
